<div class="footer-wrapper">
    <footer class="footer-text">
        <span class="col-6">
            <a href="https://github.com/Hannes221/rq-dashboard-fast">RQ-dashboard-FastAPI</a><span> version: {{
                rq_dashboard_version }}
            </span>
    </footer>
</div>